import React from 'react';
import { AxiosInstance } from 'axios';
import { i18n } from 'i18next';
export declare type WidgetTypes = 'movie' | 'people';
export declare type LanguageTypes = 'en' | 'ru';
export interface ITheme {
    colors?: {
        primary?: string;
        secondary?: string;
        success?: string;
        light?: string;
        dark?: string;
    };
}
export interface IMovie {
    poster_path: string | null;
    adult: boolean;
    overview: string;
    release_date: string;
    genre_ids: number[];
    id: number;
    original_title: string;
    original_language: LanguageTypes;
    title: string;
    backdrop_path: string | null;
    popularity: number;
    vote_count: number;
    video: boolean;
    vote_average: number;
}
export interface IPeople {
    profile_path: string;
    adult: boolean;
    id: number;
    name: string;
    popularity: number;
}
export declare type IProviderConfig = {
    theme: ITheme;
    language: LanguageTypes;
    api: AxiosInstance;
    i18n: i18n;
};
export interface IWidgetProvider {
    apiKey: string;
    theme?: ITheme;
    language?: LanguageTypes;
    children: (config: IProviderConfig) => React.ReactElement;
    className?: string;
    onError?(err: string): void;
}
export interface IListWrapperProps<T, V> {
    filter?: T | null;
    onSelect?(filter: V | null): void;
    className?: string;
    config: IProviderConfig;
}
export declare type IWidgetConfig = IListWrapperProps<IPeople, IMovie> | IListWrapperProps<IMovie, IPeople>;
export interface ICreateListBrowserWidget {
    type: WidgetTypes;
    insertId: string;
    config: IWidgetConfig;
}
export interface IListBrowserWidget extends ICreateListBrowserWidget {
    id: string;
}
export declare type Languages = LanguageTypes;
export declare type Movie = IMovie;
export declare type People = IPeople;
export declare const WidgetProvider: React.FC<IWidgetProvider>;
export declare const PeopleWidgetComponent: (props: IListWrapperProps<IMovie, IPeople>) => JSX.Element;
export declare const MovieWidgetComponent: (props: IListWrapperProps<IPeople, IMovie>) => JSX.Element;
export declare class BrowserProvider {
    private configServise;
    private widgets;
    constructor(providerProps: IWidgetProvider);
    createListWidget(props: ICreateListBrowserWidget): IListBrowserWidget;
    removeWidget(id: IListBrowserWidget['id']): void;
    updateWidget(props: IListBrowserWidget): void;
    updateLanguage(language: Languages): void;
    updateTheme(theme: ITheme): void;
    render(): void;
}
